@@ -1,9 +1,10 @@
 from .models.model_builder import ModelBuilder
 from .callbacks.callback import Callback
 from .callbacks.ckpt_callback import CkptCallback
+from .callbacks.wechat_send_msg_callback import WechatCallback
 from .callbacks.reduce_lr_on_plateau import ReduceLROnPlateau
 from .models.base_model import BaseModel
-from .utils.config import init_cfg, load_cfg
+from .utils.config import init_cfg, load_cfg, merge_cfg
 from .train import train_main
 from .metrics import measure
 from .data import *
@@ -11,5 +12,6 @@ from .models.lr_scheduler import LinearDownLR
 from .utils.dist_util import master_only, get_rank
 from .metrics  import *
 from .utils.cls_utils import new_cls 
+from .utils import logger
 
 name = "torchelper"
\ No newline at end of file
