@@ -3,12 +3,12 @@ from .dist_util import master_only
 
 @master_only
 def debug(*msg):
-    print(msg)
+    print(*msg)
 
 @master_only
 def log(*msg):
-    print(msg)
+    print(*msg)
 
 @master_only
 def warn(*msg):
-    print(msg)
\ No newline at end of file
+    print(*msg)
\ No newline at end of file
